@@ -34,7 +34,6 @@
 #include <KMenu>
 #include <KMenuBar>
 #include <KMessageBox>
-#include <KToggleAction>
 #include <KToggleFullScreenAction>
 #include <KStandardAction>
 #include <KStandardGuiItem>
@@ -508,6 +507,9 @@ bool MainWindow::queryClose()
         return true;
     }
 
+    // NOTE: Some, if not all, of the below KWindowSystem calls are only
+    //       implemented under x11 (KDE4.8 kdelibs/kdeui/windowmanagement).
+
     // make sure the window is shown on current desktop and is not minimized
     KWindowSystem::setOnDesktop(winId(), KWindowSystem::currentDesktop());
     if ( isMinimized() ) {
