@@ -472,6 +472,7 @@ void Session::run()
 
     _shellProcess->setFlowControlEnabled(_flowControlEnabled);
     _shellProcess->setEraseChar(_emulation->eraseChar());
+    _shellProcess->setUseUtmp(_addToUtmp);
 
     // this is not strictly accurate use of the COLORFGBG variable.  This does not
     // tell the terminal exactly which colors are being used, but instead approximates
@@ -490,11 +491,7 @@ void Session::run()
     const QString dbusObject = QString("/Sessions/%1").arg(QString::number(_sessionId));
     addEnvironmentEntry(QString("KONSOLE_DBUS_SESSION=%1").arg(dbusObject));
 
-    int result = _shellProcess->start(exec,
-                                      arguments,
-                                      _environment,
-                                      _addToUtmp);
-
+    int result = _shellProcess->start(exec, arguments, _environment);
     if (result < 0) {
         terminalWarning(i18n("Could not start program '%1' with arguments '%2'.", exec, arguments.join(" ")));
         return;
@@ -704,7 +701,7 @@ void Session::updateTerminalSize()
 void Session::updateWindowSize(int lines, int columns)
 {
     Q_ASSERT(lines > 0 && columns > 0);
-    _shellProcess->setWindowSize(lines, columns);
+    _shellProcess->setWindowSize(columns, lines);
 }
 void Session::refresh()
 {
@@ -723,9 +720,9 @@ void Session::refresh()
     // send an email with method or patches to konsole-devel@kde.org
 
     const QSize existingSize = _shellProcess->windowSize();
-    _shellProcess->setWindowSize(existingSize.height(), existingSize.width() + 1);
+    _shellProcess->setWindowSize(existingSize.width() + 1, existingSize.height());
     usleep(500); // introduce small delay to avoid changing size too quickly
-    _shellProcess->setWindowSize(existingSize.height(), existingSize.width());
+    _shellProcess->setWindowSize(existingSize.width(), existingSize.height());
 }
 
 bool Session::kill(int signal)
